Usage
## S3 method for class 'genlasso':
coef(object, lambda, nlam, df, type = c("primal", "dual", "both"), ...)Arguments
object
an object of class "genlasso", or an object which inherits this
class (i.e., "fusedlasso", "trendfilter").
lambda
a numeric vector of tuning parameter values at which coefficients
should be calculated. The user can choose to specify one of
lambda, nlam, or df; if none are specified,
then coefficients are returned at
nlam
an integer indicating a number of tuning parameters values at which
coefficients should be calculated. The tuning parameter values are
then chosen to be equally spaced on the log scale over the first
half of the solution path (this is if the f
df
an integer vector of degrees of freedom values at which coefficients
should be calculated. In the case that a single degrees of freedom
value appears multiple times throughout the solution path, the least
regularized solution (corresponding t
type
a character string, one of "primal", "dual", or "both", indicating
whether primal coefficients, dual coefficients, or both, should be
returned. Default is "primal", which corresponds to the solution of
the original problem.
...
additional arguments passed to coef.